==> vradi-entities-0.0.2-sources.jar: com/jurismarches/vradi/entities/Form.java <==
package com.jurismarches.vradi.entities;

import java.util.Date;
import java.util.Set;
import org.sharengo.wikitty.BusinessEntity;

public interface Form extends BusinessEntity {

	static final public String EXT_FORM = "Form";

    static final public String FIELD_NAME = "name";
    static final public String FQ_FIELD_NAME = EXT_FORM + ".name";
    static final public String FIELD_DATEPUB = "datePub";
    static final public String FQ_FIELD_DATEPUB = EXT_FORM + ".datePub";
    static final public String FIELD_STATUT = "statut";
    static final public String FQ_FIELD_STATUT = EXT_FORM + ".statut";
    static final public String FIELD_THESAURUS = "thesaurus";
    static final public String FQ_FIELD_THESAURUS = EXT_FORM + ".thesaurus";
    static final public String FIELD_DATEPEREMPTION = "datePeremption";
    static final public String FQ_FIELD_DATEPEREMPTION = EXT_FORM + ".datePeremption";
    static final public String FIELD_ID = "id";
    static final public String FQ_FIELD_ID = EXT_FORM + ".id";
    static final public String FIELD_SENDING = "sending";
    static final public String FQ_FIELD_SENDING = EXT_FORM + ".sending";

    public void setName(String name);
    public String getName();


    public void setDatePub(Date datePub);
    public Date getDatePub();


    public void setStatut(int statut);
    public int getStatut();

    public Set<String> getThesaurus();
    public void addThesaurus(String element);
    public void removeThesaurus(String element);
    public void clearThesaurus();


    public void setDatePeremption(Date datePeremption);
    public Date getDatePeremption();


    public void setId(String id);
    public String getId();

    public Set<String> getSending();
    public void addSending(String element);
    public void removeSending(String element);
    public void clearSending();


} //Form

==> vradi-entities-0.0.3-sources.jar: com/jurismarches/vradi/entities/Form.java <==
package com.jurismarches.vradi.entities;

import java.util.Date;
import java.util.Set;
import org.sharengo.wikitty.BusinessEntity;

public interface Form extends BusinessEntity {

	static final public String EXT_FORM = "Form";

    static final public String FIELD_NAME = "name";
    static final public String FQ_FIELD_NAME = EXT_FORM + ".name";
    static final public String FIELD_ID = "id";
    static final public String FQ_FIELD_ID = EXT_FORM + ".id";
    static final public String FIELD_DATEPUB = "datePub";
    static final public String FQ_FIELD_DATEPUB = EXT_FORM + ".datePub";
    static final public String FIELD_DATEPEREMPTION = "datePeremption";
    static final public String FQ_FIELD_DATEPEREMPTION = EXT_FORM + ".datePeremption";
    static final public String FIELD_THESAURUS = "thesaurus";
    static final public String FQ_FIELD_THESAURUS = EXT_FORM + ".thesaurus";
    static final public String FIELD_STATUT = "statut";
    static final public String FQ_FIELD_STATUT = EXT_FORM + ".statut";
    static final public String FIELD_SOURCE = "source";
    static final public String FQ_FIELD_SOURCE = EXT_FORM + ".source";
    static final public String FIELD_DESCRIPTION = "description";
    static final public String FQ_FIELD_DESCRIPTION = EXT_FORM + ".description";
    static final public String FIELD_INITIATEUR = "initiateur";
    static final public String FQ_FIELD_INITIATEUR = EXT_FORM + ".initiateur";
    static final public String FIELD_SENDING = "sending";
    static final public String FQ_FIELD_SENDING = EXT_FORM + ".sending";

    public void setName(String name);
    public String getName();


    public void setId(String id);
    public String getId();


    public void setDatePub(Date datePub);
    public Date getDatePub();


    public void setDatePeremption(Date datePeremption);
    public Date getDatePeremption();

    public Set<String> getThesaurus();
    public void addThesaurus(String element);
    public void removeThesaurus(String element);
    public void clearThesaurus();


    public void setStatut(int statut);
    public int getStatut();


    public void setSource(String source);
    public String getSource();


    public void setDescription(String description);
    public String getDescription();


    public void setInitiateur(String initiateur);
    public String getInitiateur();

    public Set<String> getSending();
    public void addSending(String element);
    public void removeSending(String element);
    public void clearSending();


} //Form
